
from smart_module.module_system.module_factions import factions
from smart_module.module_system.module_game_menus import game_menus
from smart_module.module_system.module_info import *
from smart_module.module_system.module_items import items
from smart_module.module_system.module_mission_templates import mission_templates
from smart_module.module_system.module_particle_systems import particle_systems
from smart_module.module_system.module_parties import parties
from smart_module.module_system.module_party_templates import party_templates
from smart_module.module_system.module_quests import quests
from smart_module.module_system.module_scripts import scripts
from smart_module.module_system.module_strings import strings
from smart_module.module_system.module_troops import troops
from smart_module.module_system.process_common import *
from smart_module.module_system.process_operations import *

tag_uses = []

def processTagsUnused(context):
  configParser = context.configParser
  export_dir = configParser.getExportDir()
  tag_uses = load_tag_uses(export_dir)
  print( "Checking tag usages...")

  #Processing strings
  length = 0
  for i in range(len(tag_uses[tag_string])):
    if tag_uses[tag_string][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_string][i] == 0:
      if i > 3:
        print( "WARNING: String is never used: " + strings[i][0].lower())

  #Processing items
  length = 0
  for i in range(len(tag_uses[tag_item])):
    if tag_uses[tag_item][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_item][i] == 0 and i > 1:
      print( "WARNING: Item is never used: " + items[i][0].lower())

  #Processing troops
  length = 0
  for i in range(len(tag_uses[tag_troop])):
    if tag_uses[tag_troop][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_troop][i] == 0:
      if i > 3:
        print( "WARNING: Troop is never used: " + troops[i][0].lower())

  #Processing factions
  length = 0
  for i in range(len(tag_uses[tag_faction])):
    if tag_uses[tag_faction][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_faction][i] == 0:
      print( "WARNING: Faction is never used: " + factions[i][0].lower())

  #Processing quests
  length = 0
  for i in range(len(tag_uses[tag_quest])):
    if tag_uses[tag_quest][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_quest][i] == 0:
      print( "WARNING: Quest is never used: " + quests[i][0].lower())

  #Processing party_templates
  length = 0
  for i in range(len(tag_uses[tag_party_tpl])):
    if tag_uses[tag_party_tpl][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_party_tpl][i] == 0:
      if i > 3:
        print( "WARNING: Party template is never used: " + party_templates[i][0].lower())

  #Processing parties
  length = 0
  for i in range(len(tag_uses[tag_party])):
    if tag_uses[tag_party][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_party][i] == 0:
      if parties[i][0].lower().find("temp_") == -1:
        print( "WARNING: Party is never used: " + parties[i][0].lower())

  #Processing scenes
  #length = 0
  #for i in range(1024):
  #  if tag_uses[tag_scene][i] > 0:
  #    length = i
  #
  #for i in range(length):
  #  if tag_uses[tag_scene][i] == 0:
  #    print( "WARNING: Scene is never used: " + scenes[i][0].lower())

  #Processing mission_templates
  length = 0
  for i in range(len(tag_uses[tag_mission_tpl])):
    if tag_uses[tag_mission_tpl][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_mission_tpl][i] == 0:
      print( "WARNING: Mission template is never used: " + mission_templates[i][0].lower())

  #Processing game_menus
  length = 0
  for i in range(len(tag_uses[tag_menu])):
    if tag_uses[tag_menu][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_menu][i] == 0 and i > 0:
      if i > 1:
        print( "WARNING: Game menu is never used: " + game_menus[i][0].lower())

  #Processing scripts
  length = 0
  for i in range(len(tag_uses[tag_script])):
    if tag_uses[tag_script][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_script][i] == 0:
      if scripts[i][0].lower().find("game_") == -1:
        print( "WARNING: Script is never used: " + scripts[i][0].lower())

  #Processing particle systems
  length = 0
  for i in range(len(tag_uses[tag_particle_sys])):
    if tag_uses[tag_particle_sys][i] > 0:
      length = i

  for i in range(length):
    if tag_uses[tag_particle_sys][i] == 0:
      if particle_systems[i][0].lower().find("game_") == -1:
        print( "WARNING: Particle system is never used: " + particle_systems[i][0].lower())

  #Processing scene props
  #length = 0
  #for i in range(1024):
  #  if tag_uses[tag_scene_prop][i] > 0:
  #    length = i
  #
  #for i in range(length):
  #  if tag_uses[tag_scene_prop][i] == 0:
  #    print( "WARNING: Scene prop is never used: " + scene_props[i][0].lower())

  #Processing sounds
  #length = 0
  #for i in range(1024):
  #  if tag_uses[tag_sound][i] > 0:
  #    length = i
  #
  #for i in range(length):
  #  if tag_uses[tag_sound][i] == 0:
  #    print( "WARNING: Sound is never used: " + sounds[i][0].lower())

  #Processing map icons
  #length = 0
  #for i in range(1024):
  #  if tag_uses[tag_map_icon][i] > 0:
  #    length = i
  #
  #for i in range(length):
  #  if tag_uses[tag_map_icon][i] == 0:
  #    print( "WARNING: Map icon is never used: " + map_icons[i][0].lower())



###################################################
# header_game_menus.py
# This file contains declarations for game menus
# DO NOT EDIT THIS FILE!
###################################################

from smart_module.module_system.header_common import *
from smart_module.module_system.header_operations import *
from smart_module.module_system.header_item_modifiers import *
from smart_module.module_system.header_skills import *
from smart_module.module_system.header_troops import *

#menu flags:
mnf_join_battle            = 0x00000001 #Consider this menu when the player joins a battle
mnf_auto_enter             = 0x00000010 #Automatically enter the town with the first menu option. 
mnf_enable_hot_keys        = 0x00000100 #Enables P,I,C keys
mnf_disable_all_keys       = 0x00000200 #Disables all keys
mnf_scale_picture          = 0x00001000 #Scale menu picture to offest screen aspect ratio

def menu_text_color(color):
  return color << 32



track_bogus = 0
track_mount_and_blade_title_screen = 1
track_ambushed_by_neutral = 2
track_ambushed_by_khergit = 3
track_ambushed_by_nord = 4
track_ambushed_by_rhodok = 5
track_ambushed_by_swadian = 6
track_ambushed_by_vaegir = 7
track_ambushed_by_sarranid = 8
track_arena_1 = 9
track_armorer = 10
track_bandit_fight = 11
track_calm_night_1 = 12
track_captured = 13
track_defeated_by_neutral = 14
track_defeated_by_neutral_2 = 15
track_defeated_by_neutral_3 = 16
track_empty_village = 17
track_encounter_hostile_nords = 18
track_escape = 19
track_fight_1 = 20
track_fight_2 = 21
track_fight_3 = 22
track_fight_as_khergit = 23
track_fight_4 = 24
track_fight_as_nord = 25
track_fight_as_rhodok = 26
track_fight_as_vaegir = 27
track_fight_while_mounted_1 = 28
track_fight_while_mounted_2 = 29
track_fight_while_mounted_3 = 30
track_infiltration_khergit = 31
track_killed_by_khergit = 32
track_killed_by_swadian = 33
track_lords_hall_khergit = 34
track_lords_hall_nord = 35
track_lords_hall_swadian = 36
track_lords_hall_rhodok = 37
track_lords_hall_vaegir = 38
track_mounted_snow_terrain_calm = 39
track_neutral_infiltration = 40
track_outdoor_beautiful_land = 41
track_retreat = 42
track_seige_neutral = 43
track_enter_the_juggernaut = 44
track_siege_attempt = 45
track_crazy_battle_music = 46
track_tavern_1 = 47
track_tavern_2 = 48
track_town_neutral = 49
track_town_khergit = 50
track_town_nord = 51
track_town_rhodok = 52
track_town_swadian = 53
track_town_vaegir = 54
track_travel_khergit = 55
track_travel_neutral = 56
track_travel_nord = 57
track_travel_rhodok = 58
track_travel_swadian = 59
track_travel_vaegir = 60
track_travel_sarranid = 61
track_uncertain_homestead = 62
track_hearth_and_brotherhood = 63
track_tragic_village = 64
track_victorious_evil = 65
track_victorious_neutral_1 = 66
track_victorious_neutral_2 = 67
track_victorious_neutral_3 = 68
track_victorious_swadian = 69
track_victorious_vaegir = 70
track_victorious_vaegir_2 = 71
track_wedding = 72
track_coronation = 73





# from smart_module.smart_modules.center.village.VillageBasicBusiness import initWorkShop, workShopPropertyCount, \
#     productPropertyCount
#
# if __name__ == '__main__':
#     aaa = initWorkShop()


## 用于编写一些ai方面的功能
from smart_module.module_system.header_operations import *
from smart_module.module_system.header_parties import *
from smart_module.module_system.module_constants import *

aiBaseScripts={
    "name":"AiBaseScripts",
    "enable":True,
    "version":"v2.0.0",
    "desc":"与AI相关的操作",
    "actions":[
        ("Append@scripts",[
            ## 移动到某个据点
            ("set_party_ai_go_to_center",[
                (store_script_param_1,":party"),
                (store_script_param_2,":center"),
                (party_set_slot, ":party", slot_party_ai_state, spai_trading_with_town),
                (party_set_slot, ":party", slot_party_ai_object, ":center"),
                (party_set_ai_behavior, ":party", ai_bhvr_travel_to_party),
                (party_set_ai_object, ":party", ":center"),
            ]),
            ## 巡逻某个据点
            ("set_party_ai_patrol_center",[
                (store_script_param,":party",1),
                (store_script_param,":town",2),
                (store_script_param,":radius",3),

                (try_begin),
                    (le,":radius",0),
                    (assign,":radius",20),
                (try_end),

                (party_set_slot, ":party", slot_party_ai_state, spai_patrolling_around_center),
                (party_set_slot, ":party", slot_party_ai_object, ":town"),
                (party_set_ai_behavior, ":party", ai_bhvr_patrol_party),
                (party_set_ai_object, ":party", ":town"),
                (party_set_ai_patrol_radius,":party",":radius")
            ]),
        ])
    ],
}


from smart_module.module_system.ID_factions import fac_commoners
from smart_module.module_system.header_game_menus import *
from smart_module.module_system.header_operations import *
from smart_module.module_system.header_skills import *
from smart_module.module_system.header_terrain_types import *
from smart_module.module_system.header_troops import *
from smart_module.module_system.module_constants import *
from smart_module.module_system.module_troops import *
from smart_module.smart_core.utils.pythonUtils import mergeList
from smart_module.smart_modules.base.StringBaseScripts import skill_str_begin

config = {
    ## 进度更新时间
    "updateTime":0.25,
    "skill":skl_engineer,
    ## 图纸列表
    "blueprintList":[
        {
            "typeName":"dagger",
            "typeNameCn":"匕 首",
            "reward":"itm_dagger",
            ## 制作最低【工程师】级别
            "skillLevel":1,
            ## 制作花费时间
            "makeCostTime":2,
            ## 制作花费的金额
            "makeCostMoney":10,
            ## 学习如何制作花费的时间
            "learnCostTime":2,
            ## 学习到的机率（100:代表一定学会）
            "learnProbability":100,
            "materialList":[
                {
                    "material":"itm_iron",
                    "amount":1
                },
                {
                    "material":"itm_wooden_stick",
                    "amount":1
                },
            ],
            ## 描述信息
            "desc":"最简单的图纸"
        },
    ]
}



## 收获时间
updateTime = config.get("updateTime")
skill = config.get("skill")
blueprintList = config.get("blueprintList")
## 测试
updateTime = 1


systemBlueprintList = "trp_system_blueprint_list"
playerBlueprintList = "trp_player_blueprint_list"

def initHandicraftIndustry():
    ## 图纸列表
    blueprintMenusList = []
    ## 图纸选项列表
    blueprintMenusOptions = []
    blueprintCnsList = []
    blueprintCommandList = []
    for index in range(len(blueprintList)):
        blueprint = blueprintList[index]
        typeName = blueprint.get("typeName")
        plantNameCn = blueprint.get("plantNameCn")
        reward = blueprint.get("reward")
        skillLevel = blueprint.get("skillLevel")
        makeCostTime = blueprint.get("makeCostTime")
        makeCostMoney = blueprint.get("makeCostMoney")
        learnCostTime = blueprint.get("learnCostTime")
        learnProbability = blueprint.get("learnProbability")
        materialList = blueprint.get("materialList")

        ## 保存系统蓝图的列表
        blueprintCommandList.append((troop_set_slot,systemBlueprintList,index,reward))


        optionName = "handicraft_" + typeName
        blueprintCnsList.append("mno_{}|{}（{}）".format(optionName,plantNameCn,skillLevel))
        blueprintOptions.append((
            optionName,[
                ## 玩家已经学会
                (neg|eq,"$g_farmer_plant_type",plantType),
                ## 玩家级别超过限制
                (store_skill_level, ":skillCount", skill),
                (ge,":skillCount",skillLevel),
            ], plantName,[
                (eq, "$g_farmer_land_process", flp_none),
                (assign, "$g_farmer_plant_type", plantType),
                (assign, "$g_farmer_plant_fee", plantFee),
                (assign, "$g_farmer_plant_time", plantTime),
                (assign, "$g_farmer_plant_quantity", plantQuantity),
                (str_store_item_name,s0,plantType),
                (display_message, "@farmer change {s0}"),
                ## 切换到上一层菜单
                (jump_to_menu, "mnu_land_manage_options"),
            ]
        ))
    blueprintOptions.append(("farmer_change_seed_keep",[], "back",
                 [
                    (jump_to_menu, "mnu_land_manage_options"),
                 ]),)
    blueprintCnsList.append("mno_farmer_change_seed_keep|返 回")
    return {
        "plantOptions":plantOptions,
        "plantCnsList":plantCnsList,
    }


datas = initHandicraftIndustry()

gameMenuOptionList = datas.get("gameMenuOptionList")
gameStringsList = datas.get("gameStringsList")

## $g_survival_enable

is_normal = 0 ## 正常
is_working = 1 ## 工作中

pis_workman = 3


WARN_COLOR = 0xfffc9f03


handicraftIndustry={
    "name":"HandicraftIndustry",
    "enable":True,
    "version": "v2.0.0",
    "desc":'''
        打造系统
            可以手工打造一些物品
            1.匕首
    ''',
    "actions":[
        ("AppendCustomArrayTroop",[
            ## 用于保存所有的蓝图列表
            ["system_blueprint_list", "system blueprint list", "system blueprint list", tf_hero, no_scene, reserved, fac_commoners, [],
             def_attrib, 0, knows_common | knows_inventory_management_10, 0],
            ## 用于保存玩家学会的蓝图列表（会：1，不会：0）
            ["player_blueprint_list", "player blueprint list", "player blueprint list", tf_hero, no_scene, reserved, fac_commoners, [],
             def_attrib, 0, knows_common | knows_inventory_management_10, 0],
        ]),
        ## 在营地增加一个选项
        ("AddCampOption",[
            ("camp_action_open_blueprint_list", [], "open blueprint list",
             [
                (jump_to_menu,"mnu_blueprint_list"),
             ]
            ),
        ]),
        ("Append@game_menus",[
            ## 图纸列表
            ("blueprint_list", mnf_disable_all_keys,
             "blueprint list",
             "none",
             [],
             gameMenuOptionList
             ),
            ## 图纸选项组
            ("blueprint_options", mnf_disable_all_keys,
             "blueprint options",
             "none",
             [],
             gameMenuOptionList
             ),
        ]),





        ("Append@scripts",[
            ("start_work_at_wild",[
                ##(assign,"$g_camp_mode", 1),
                ##(assign, "$g_infinite_camping", 0),
                ##(assign, "$g_player_icon_state", pis_ship),

                (store_skill_level,":probabilitySkillCount","$g_survival_probabilitySkill"),
                (str_store_troop_name,s0,"trp_player"),
                (try_begin),
                    (le,":probabilitySkillCount",0),
                    (store_mul,":strIndex","$g_survival_probabilitySkill",2),
                    (val_add,":strIndex",skill_str_begin),
                    (str_store_string,s1,":strIndex"),
                    (display_message,"@{s0} need skill {s1}",WARN_COLOR),
                (else_try),
                    (assign,"$g_player_icon_state",pis_workman),
                    (rest_for_hours_interactive, 100000, 5, 1), #rest while not attackable
                    (assign,"$g_survival_enable",is_working),
                    (change_screen_return),
                (try_end),
            ]),
        ]),
        ("Append@simple_triggers",[
            (harvestTime,[
                ## 已经开启了野外生存
                (eq,"$g_survival_enable",is_working),
                (store_skill_level,":probabilitySkillCount","$g_survival_probabilitySkill"),
                (str_store_troop_name,s0,"trp_player"),
                (store_mul, ":probabilitySkillEnhance", ":probabilitySkillCount", "$g_survival_probabilitySkillEnhance"),
                ## 获得总机率
                (store_add, ":change", "$g_survival_probability", ":probabilitySkillEnhance"),
                ## 机率最大为100%
                (val_clamp, ":change", 0, 100),
                (store_random_in_range, ":isGet", 0, 100),
                ## 是否成功获得
                (le, ":isGet", ":change"),
                (store_skill_level, ":amountSkillCount", "$g_survival_amountSkill"),
                (store_mul, ":amountSkillEnhance", ":amountSkillCount", "$g_survival_amountSkillEnhance"),
                ## 数量技能增加最100%
                (val_clamp, ":amountSkillEnhance", 0, 100),
                (store_mul, ":plusAmount", "$g_survival_amount", ":amountSkillEnhance"),
                (store_add, ":total", "$g_survival_amount", ":plusAmount"),
                (call_script, "script_get_troop_inventory_free_amount", "trp_player"),
                (assign, ":storageMax", reg0),
                (try_begin),
                    (eq, ":storageMax", 0),
                    (assign, "$g_survival_enable", is_normal),
                    (assign, "$g_player_icon_state", pis_normal),
                    (rest_for_hours, 0, 0, 0),
                    (display_message, "@{s0} storage is full",WARN_COLOR),
                (else_try),
                    (troop_add_items, "trp_player", "$g_survival_reward", ":total"),
                (try_end),
             ]),
            (0,[
                (eq,"$g_survival_enable",is_working),
                (map_free),
                (assign,"$g_survival_enable",is_normal),
                (assign, "$g_player_icon_state", pis_normal),
             ])
        ]),
        ("AddCampOption",[
            ("camp_action_survival_in_the_wild", [], "survival in the wild",
             [
                (jump_to_menu,"mnu_survival_wild"),
             ]
            ),
        ]),
        ("Append@game_menus",[
            ("survival_wild", mnf_disable_all_keys,
             "survival in the wild.",
             "none",
             [],
             gameMenuOptionList
             ),
        ]),
        ("Replace@simple_triggers|#60",[
            (0,[
                (troop_get_inventory_slot, ":cur_horse", "trp_player", 8), #horse slot
                (assign, ":new_icon", -1),
                (try_begin),
                  (eq, "$g_player_icon_state", pis_normal),
                  (try_begin),
                    (ge, ":cur_horse", 0),
                    (assign, ":new_icon", "icon_player_horseman"),
                  (else_try),
                    (assign, ":new_icon", "icon_player"),
                  (try_end),
                (else_try),
                  (eq, "$g_player_icon_state", pis_camping),
                  (assign, ":new_icon", "icon_camp"),
                (else_try),
                  (eq, "$g_player_icon_state", pis_ship),
                  (assign, ":new_icon", "icon_ship"),
                (else_try),
                  (eq, "$g_player_icon_state", pis_workman),
                  (assign, ":new_icon", "icon_axeman"),
                (try_end),
                (neq, ":new_icon", "$g_player_party_icon"),
                (assign, "$g_player_party_icon", ":new_icon"),
                (party_set_icon, "p_main_party", ":new_icon"),
             ])
        ])
    ],
    "internationals":{
            "cns":{
                "game_menus":mergeList(gameStringsList,[
                    "mno_camp_action_survival_in_the_wild|野 外 生 存。",
                    "menu_survival_wild|野 外 生 存 技 能"
                ]),
                "quick_strings":[
                    "qstr_{s0}_need_skill_{s1}|{s0}：我 还 不 会 【{s1}】 技 能",
                    "qstr_{s0}_storage_is_full|{s0}：物 品 栏 已 经 满 了。"
                ]
            }
    }
}


# -*- coding: utf-8 -*-

from smart_module.module_system.header_operations import *
from smart_module.module_system.header_parties import *
from smart_module.module_system.module_constants import *


# '''
#     功能大概如下：
#     1.出城游玩（非战争期间）
#     2.打击劫匪
#     3.被俘虏交赎金（玩家）
# '''

'''

    女主出游：在没有战争时期，女主们会组织一小队人游山玩水。
'''

## 女士队伍小于人时开始招募士兵


lady_party_min_count = 17

## 敌国数量小于多少时才出来(等于0时代表没有任何战争时才出来游玩)
lady_can_go_out_enemy_state_num = 0

## 出游更新时间
lady_go_out_update_time = 12


ladiesGoOut={
    "name":"LadiesGoOut",
    "enable":True,
    "dependentOn":["PartyBaseScripts","FactionBaseScripts"],
    "version": "v2.0.0",
    "desc":"女主出游，在没有战争时期，女主们会组织一小队人游山玩水。",
    "actions": [
        ("GameInitScript",[
            (call_script, "script_ladies_go_out"),
        ]),
        ("Append@simple_triggers",[
            (lady_go_out_update_time, [
                (call_script, "script_ladies_go_out"),
            ]),
        ]),
        ("Append@scripts",[
            ("ladies_go_out", [
                # (display_message,"@ladies go out start"),
                (try_for_range, ":lady_no", kingdom_ladies_begin, kingdom_ladies_end),
                ## 获领导的队伍
                (troop_get_slot, ":lead_party", ":lady_no", slot_troop_leaded_party),
                ## 是否有交战
                (store_faction_of_troop, ":faction", ":lady_no"),
                ## 必须是当前活跃阵营
                (is_between, ":faction", kingdoms_begin, kingdoms_end),
                (call_script, "script_get_num_of_enemy_state", ":faction"),
                (assign, ":enemy_state_num", reg0),
                (try_begin),
                ## 非战争时期
                (le, ":enemy_state_num", lady_can_go_out_enemy_state_num),
                # (troop_get_slot,":home",":lady_no",slot_troop_home),
                (troop_get_slot, ":home", ":lady_no", slot_troop_cur_center),
                # (str_store_troop_name,s1,":lady_no"),
                # (str_store_party_name,s2,":home"),
                # (display_message,"@lady({s1})'home is {s2}"),
                # (assign,reg1,":lead_party"),
                # (display_message,"@lead_party id is {reg1}"),
                (try_begin),
                ## 没有领导的队伍
                (le, ":lead_party", 0),
                ## 没有被人俘虏
                (neg | troop_slot_ge, ":lady_no", slot_troop_prisoner_of_party, 0),
                ## 创建部队(-1代表使用默认值)
                (call_script, "script_create_party", ":lady_no", ":home", -1, -1, -1, spt_kingdom_hero_party,
                 "icon_woman_b", -1),
                (assign, ":lady_party", reg0),
                ## 增加士兵
                (call_script, "script_party_add_members", ":lady_party", -1, 5, -1, 0, 10),
                ## 增加经验
                (call_script, "script_party_add_xp_and_upgrade", ":lady_party", 20, 100),
                ## 设置ai
                ##(call_script, "script_party_set_ai_state", ":lady_party",  spai_patrolling_around_center, ":home"),
                (call_script, "script_party_change_ai_state", ":lady_party", ai_bhvr_patrol_party, ":home", 5),
                # (str_store_party_name,s1,":lady_party"),
                # (display_message,"@lady party({s1}) be created"),
                (call_script, "script_troop_leave_home", ":lady_no"),
                (else_try),
                (party_get_num_companions, ":size", ":lead_party"),
                (lt, ":size", lady_party_min_count),
                ## 增加士兵
                (call_script, "script_party_add_members", ":lead_party", -1, 1, -1, 0, 10),
                ## 增加经验
                (call_script, "script_party_add_xp_and_upgrade", ":lead_party", 3, 100),
                # (str_store_party_name,s1,":lead_party"),
                # (display_message,"@lady party({s1}) is update"),
                (try_end),
                (else_try),
                # 有战争时,不会出外游玩
                (gt, ":lead_party", 0),
                # (str_store_party_name,s1,":lead_party"),
                # (display_message,"@lady party({s1}) is go home"),
                (remove_party, ":lead_party"),
                (troop_set_slot, ":lady_no", slot_troop_leaded_party, -1),
                (call_script, "script_troop_go_home", ":lady_no"),
                (try_end),
                (try_end),
            ]),
        ]),
    ],
}


from smart_module.module_system.header_map_icons import *
from smart_module.module_system.module_constants import *
from smart_module.module_system.header_operations import *
from smart_module.module_system.header_triggers import *
from smart_module.module_system.ID_sounds import *

####################################################################################################################
#  Each map icon record contains the following fields:
#  1) Map icon id: used for referencing map icons in other files.
#     The prefix icon_ is automatically added before each map icon id.
#  2) Map icon flags. See header_map icons.py for a list of available flags
#  3) Mesh name.
#  4) Scale. 
#  5) Sound.
#  6) Offset x position for the flag icon.
#  7) Offset y position for the flag icon.
#  8) Offset z position for the flag icon.
####################################################################################################################

banner_scale = 0.3
avatar_scale = 0.15

map_icons = [
  ("player",0,"player", avatar_scale, snd_footstep_grass, 0.15, 0.173, 0),
  ("player_horseman",0,"player_horseman", avatar_scale, snd_gallop, 0.15, 0.173, 0),
  ("gray_knight",0,"knight_a", avatar_scale, snd_gallop, 0.15, 0.173, 0),
  ("vaegir_knight",0,"knight_b", avatar_scale, snd_gallop, 0.15, 0.173, 0),
  ("flagbearer_a",0,"flagbearer_a", avatar_scale, snd_gallop, 0.15, 0.173, 0),
  ("flagbearer_b",0,"flagbearer_b", avatar_scale, snd_gallop, 0.15, 0.173, 0),
  ("peasant",0,"peasant_a", avatar_scale,snd_footstep_grass, 0.15, 0.173, 0),
  ("khergit",0,"khergit_horseman", avatar_scale,snd_gallop, 0.15, 0.173, 0),
  ("khergit_horseman_b",0,"khergit_horseman_b", avatar_scale,snd_gallop, 0.15, 0.173, 0),
  ("axeman",0,"bandit_a", avatar_scale,snd_footstep_grass, 0.15, 0.173, 0),
  ("woman",0,"woman_a", avatar_scale,snd_footstep_grass, 0.15, 0.173, 0),
  ("woman_b",0,"woman_b", avatar_scale,snd_footstep_grass, 0.15, 0.173, 0),
  ("town",mcn_no_shadow,"map_town_a", 0.35,0),
  ("town_steppe",mcn_no_shadow,"map_town_steppe_a", 0.35,0),
  ("town_desert",mcn_no_shadow,"map_town_desert_a", 0.35,0),
  ("village_a",mcn_no_shadow,"map_village_a", 0.45, 0),
  ("village_b",mcn_no_shadow,"map_village_b", 0.45, 0),
  ("village_c",mcn_no_shadow,"map_village_c", 0.45, 0),
  ("village_burnt_a",mcn_no_shadow,"map_village_burnt_a", 0.45, 0),
  ("village_deserted_a",mcn_no_shadow,"map_village_deserted_a", 0.45, 0),
  ("village_burnt_b",mcn_no_shadow,"map_village_burnt_b", 0.45, 0),
  ("village_deserted_b",mcn_no_shadow,"map_village_deserted_b", 0.45, 0),
  ("village_burnt_c",mcn_no_shadow,"map_village_burnt_c", 0.45, 0),
  ("village_deserted_c",mcn_no_shadow,"map_village_deserted_c", 0.45, 0),
  ("village_snow_a",mcn_no_shadow,"map_village_snow_a", 0.45, 0),
  ("village_snow_burnt_a",mcn_no_shadow,"map_village_snow_burnt_a", 0.45, 0),
  ("village_snow_deserted_a",mcn_no_shadow,"map_village_snow_deserted_a", 0.45, 0),


  ("camp",mcn_no_shadow,"camp_tent", 0.13, 0),
  ("ship",mcn_no_shadow,"boat_sail_on", 0.23, snd_footstep_grass, 0.0, 0.05, 0),
  ("ship_on_land",mcn_no_shadow,"boat_sail_off", 0.23, 0),

  ("castle_a",mcn_no_shadow,"map_castle_a", 0.35,0),
  ("castle_b",mcn_no_shadow,"map_castle_b", 0.35,0),
  ("castle_c",mcn_no_shadow,"map_castle_c", 0.35,0),
  ("castle_d",mcn_no_shadow,"map_castle_d", 0.35,0),
  ("town_snow",mcn_no_shadow,"map_town_snow_a", 0.35,0),


  ("castle_snow_a",mcn_no_shadow,"map_castle_snow_a", 0.35,0),
  ("castle_snow_b",mcn_no_shadow,"map_castle_snow_b", 0.35,0),
  ("mule",0,"icon_mule", 0.2,snd_footstep_grass, 0.15, 0.173, 0),
  ("cattle",0,"icon_cow", 0.2,snd_footstep_grass, 0.15, 0.173, 0),
  ("training_ground",mcn_no_shadow,"training", 0.35,0),

  ("bridge_a",mcn_no_shadow,"map_river_bridge_a", 1.27,0),
  ("bridge_b",mcn_no_shadow,"map_river_bridge_b", 0.7,0),
  ("bridge_snow_a",mcn_no_shadow,"map_river_bridge_snow_a", 1.27,0),

  ("custom_banner_01",0,"custom_map_banner_01", banner_scale, 0,
   [
     (ti_on_init_map_icon,
      [
        (store_trigger_param_1, ":party_no"),
        (party_get_slot, ":leader_troop", ":party_no", slot_town_lord),
        (try_begin),
          (ge, ":leader_troop", 0),
          (cur_map_icon_set_tableau_material, "tableau_custom_banner_square", ":leader_troop"),
        (try_end),
        ]),
     ]),
  ("custom_banner_02",0,"custom_map_banner_02", banner_scale, 0,
   [
     (ti_on_init_map_icon,
      [
        (store_trigger_param_1, ":party_no"),
        (party_get_slot, ":leader_troop", ":party_no", slot_town_lord),
        (try_begin),
          (ge, ":leader_troop", 0),
          (cur_map_icon_set_tableau_material, "tableau_custom_banner_short", ":leader_troop"),
        (try_end),
        ]),
     ]),
  ("custom_banner_03",0,"custom_map_banner_03", banner_scale, 0,
   [
     (ti_on_init_map_icon,
      [
        (store_trigger_param_1, ":party_no"),
        (party_get_slot, ":leader_troop", ":party_no", slot_town_lord),
        (try_begin),
          (ge, ":leader_troop", 0),
          (cur_map_icon_set_tableau_material, "tableau_custom_banner_tall", ":leader_troop"),
        (try_end),
        ]),
     ]),

  # Banners
  ("banner_01",0,"map_flag_01", banner_scale,0),
  ("banner_02",0,"map_flag_02", banner_scale,0),
  ("banner_03",0,"map_flag_03", banner_scale,0),
  ("banner_04",0,"map_flag_04", banner_scale,0),
  ("banner_05",0,"map_flag_05", banner_scale,0),
  ("banner_06",0,"map_flag_06", banner_scale,0),
  ("banner_07",0,"map_flag_07", banner_scale,0),
  ("banner_08",0,"map_flag_08", banner_scale,0),
  ("banner_09",0,"map_flag_09", banner_scale,0),
  ("banner_10",0,"map_flag_10", banner_scale,0),
  ("banner_11",0,"map_flag_11", banner_scale,0),
  ("banner_12",0,"map_flag_12", banner_scale,0),
  ("banner_13",0,"map_flag_13", banner_scale,0),
  ("banner_14",0,"map_flag_14", banner_scale,0),
  ("banner_15",0,"map_flag_f21", banner_scale,0),
  ("banner_16",0,"map_flag_16", banner_scale,0),
  ("banner_17",0,"map_flag_17", banner_scale,0),
  ("banner_18",0,"map_flag_18", banner_scale,0),
  ("banner_19",0,"map_flag_19", banner_scale,0),
  ("banner_20",0,"map_flag_20", banner_scale,0),
  ("banner_21",0,"map_flag_21", banner_scale,0),
  ("banner_22",0,"map_flag_22", banner_scale,0),
  ("banner_23",0,"map_flag_23", banner_scale,0),
  ("banner_24",0,"map_flag_24", banner_scale,0),
  ("banner_25",0,"map_flag_25", banner_scale,0),
  ("banner_26",0,"map_flag_26", banner_scale,0),
  ("banner_27",0,"map_flag_27", banner_scale,0),
  ("banner_28",0,"map_flag_28", banner_scale,0),
  ("banner_29",0,"map_flag_29", banner_scale,0),
  ("banner_30",0,"map_flag_30", banner_scale,0),
  ("banner_31",0,"map_flag_31", banner_scale,0),
  ("banner_32",0,"map_flag_32", banner_scale,0),
  ("banner_33",0,"map_flag_33", banner_scale,0),
  ("banner_34",0,"map_flag_34", banner_scale,0),
  ("banner_35",0,"map_flag_35", banner_scale,0),
  ("banner_36",0,"map_flag_36", banner_scale,0),
  ("banner_37",0,"map_flag_37", banner_scale,0),
  ("banner_38",0,"map_flag_38", banner_scale,0),
  ("banner_39",0,"map_flag_39", banner_scale,0),
  ("banner_40",0,"map_flag_40", banner_scale,0),
  ("banner_41",0,"map_flag_41", banner_scale,0),
  ("banner_42",0,"map_flag_42", banner_scale,0),
  ("banner_43",0,"map_flag_43", banner_scale,0),
  ("banner_44",0,"map_flag_44", banner_scale,0),
  ("banner_45",0,"map_flag_45", banner_scale,0),
  ("banner_46",0,"map_flag_46", banner_scale,0),
  ("banner_47",0,"map_flag_47", banner_scale,0),
  ("banner_48",0,"map_flag_48", banner_scale,0),
  ("banner_49",0,"map_flag_49", banner_scale,0),
  ("banner_50",0,"map_flag_50", banner_scale,0),
  ("banner_51",0,"map_flag_51", banner_scale,0),
  ("banner_52",0,"map_flag_52", banner_scale,0),
  ("banner_53",0,"map_flag_53", banner_scale,0),
  ("banner_54",0,"map_flag_54", banner_scale,0),
  ("banner_55",0,"map_flag_55", banner_scale,0),
  ("banner_56",0,"map_flag_56", banner_scale,0),
  ("banner_57",0,"map_flag_57", banner_scale,0),
  ("banner_58",0,"map_flag_58", banner_scale,0),
  ("banner_59",0,"map_flag_59", banner_scale,0),
  ("banner_60",0,"map_flag_60", banner_scale,0),
  ("banner_61",0,"map_flag_61", banner_scale,0),
  ("banner_62",0,"map_flag_62", banner_scale,0),
  ("banner_63",0,"map_flag_63", banner_scale,0),
  ("banner_64",0,"map_flag_d01", banner_scale,0),
  ("banner_65",0,"map_flag_d02", banner_scale,0),
  ("banner_66",0,"map_flag_d03", banner_scale,0),
  ("banner_67",0,"map_flag_d04", banner_scale,0),
  ("banner_68",0,"map_flag_d05", banner_scale,0),
  ("banner_69",0,"map_flag_d06", banner_scale,0),
  ("banner_70",0,"map_flag_d07", banner_scale,0),
  ("banner_71",0,"map_flag_d08", banner_scale,0),
  ("banner_72",0,"map_flag_d09", banner_scale,0),
  ("banner_73",0,"map_flag_d10", banner_scale,0),
  ("banner_74",0,"map_flag_d11", banner_scale,0),
  ("banner_75",0,"map_flag_d12", banner_scale,0),
  ("banner_76",0,"map_flag_d13", banner_scale,0),
  ("banner_77",0,"map_flag_d14", banner_scale,0),
  ("banner_78",0,"map_flag_d15", banner_scale,0),
  ("banner_79",0,"map_flag_d16", banner_scale,0),
  ("banner_80",0,"map_flag_d17", banner_scale,0),
  ("banner_81",0,"map_flag_d18", banner_scale,0),
  ("banner_82",0,"map_flag_d19", banner_scale,0),
  ("banner_83",0,"map_flag_d20", banner_scale,0),
  ("banner_84",0,"map_flag_d21", banner_scale,0),
  ("banner_85",0,"map_flag_e01", banner_scale,0),
  ("banner_86",0,"map_flag_e02", banner_scale,0),
  ("banner_87",0,"map_flag_e03", banner_scale,0),
  ("banner_88",0,"map_flag_e04", banner_scale,0),
  ("banner_89",0,"map_flag_e05", banner_scale,0),
  ("banner_90",0,"map_flag_e06", banner_scale,0),
  ("banner_91",0,"map_flag_e07", banner_scale,0),
  ("banner_92",0,"map_flag_e08", banner_scale,0),
  ("banner_93",0,"map_flag_e09", banner_scale,0),
  ("banner_94",0,"map_flag_e10", banner_scale,0),
  ("banner_95",0,"map_flag_e11", banner_scale,0),
  ("banner_96",0,"map_flag_e12", banner_scale,0),
  ("banner_97",0,"map_flag_e13", banner_scale,0),
  ("banner_98",0,"map_flag_e14", banner_scale,0),
  ("banner_99",0,"map_flag_e15", banner_scale,0),
  ("banner_100",0,"map_flag_e16", banner_scale,0),
  ("banner_101",0,"map_flag_e17", banner_scale,0),
  ("banner_102",0,"map_flag_e18", banner_scale,0),
  ("banner_103",0,"map_flag_e19", banner_scale,0),
  ("banner_104",0,"map_flag_e20", banner_scale,0),
  ("banner_105",0,"map_flag_e21", banner_scale,0),

  ("banner_106",0,"map_flag_f01", banner_scale,0),
  ("banner_107",0,"map_flag_f02", banner_scale,0),
  ("banner_108",0,"map_flag_f03", banner_scale,0),
  ("banner_109",0,"map_flag_f04", banner_scale,0),
  ("banner_110",0,"map_flag_f05", banner_scale,0),
  ("banner_111",0,"map_flag_f06", banner_scale,0),
  ("banner_112",0,"map_flag_f07", banner_scale,0),
  ("banner_113",0,"map_flag_f08", banner_scale,0),
  ("banner_114",0,"map_flag_f09", banner_scale,0),
  ("banner_115",0,"map_flag_f10", banner_scale,0),
  ("banner_116",0,"map_flag_f11", banner_scale,0),
  ("banner_117",0,"map_flag_f12", banner_scale,0),
  ("banner_118",0,"map_flag_f13", banner_scale,0),
  ("banner_119",0,"map_flag_f14", banner_scale,0),
  ("banner_120",0,"map_flag_f15", banner_scale,0),
  ("banner_121",0,"map_flag_f16", banner_scale,0),
  ("banner_122",0,"map_flag_f17", banner_scale,0),
  ("banner_123",0,"map_flag_f18", banner_scale,0),
  ("banner_124",0,"map_flag_f19", banner_scale,0),
  ("banner_125",0,"map_flag_f20", banner_scale,0),

  ("banner_126",0,"map_flag_f01", banner_scale,0),
  ("banner_127",0,"map_flag_f02", banner_scale,0),
  ("banner_128",0,"map_flag_f03", banner_scale,0),
  ("banner_129",0,"map_flag_f04", banner_scale,0),
  ("banner_130",0,"map_flag_f05", banner_scale,0),
  ("banner_131",0,"map_flag_f06", banner_scale,0),
  ("banner_132",0,"map_flag_f07", banner_scale,0),
  ("banner_133",0,"map_flag_f08", banner_scale,0),
  ("banner_134",0,"map_flag_f09", banner_scale,0),
  ("banner_135",0,"map_flag_f10", banner_scale,0),
  
  ("map_flag_kingdom_a",0,"map_flag_kingdom_a", banner_scale,0),
  ("map_flag_kingdom_b",0,"map_flag_kingdom_b", banner_scale,0),
  ("map_flag_kingdom_c",0,"map_flag_kingdom_c", banner_scale,0),
  ("map_flag_kingdom_d",0,"map_flag_kingdom_d", banner_scale,0),
  ("map_flag_kingdom_e",0,"map_flag_kingdom_e", banner_scale,0),
  ("map_flag_kingdom_f",0,"map_flag_kingdom_f", banner_scale,0),
  ("banner_136",0,"map_flag_15", banner_scale,0),
  ("bandit_lair",mcn_no_shadow,"map_bandit_lair", 0.45, 0),
]



fac_no_faction = 0
fac_commoners = 1
fac_outlaws = 2
fac_neutral = 3
fac_innocents = 4
fac_merchants = 5
fac_dark_knights = 6
fac_culture_1 = 7
fac_culture_2 = 8
fac_culture_3 = 9
fac_culture_4 = 10
fac_culture_5 = 11
fac_culture_6 = 12
fac_player_faction = 13
fac_player_supporters_faction = 14
fac_kingdom_1 = 15
fac_kingdom_2 = 16
fac_kingdom_3 = 17
fac_kingdom_4 = 18
fac_kingdom_5 = 19
fac_kingdom_6 = 20
fac_kingdoms_end = 21
fac_robber_knights = 22
fac_khergits = 23
fac_black_khergits = 24
fac_manhunters = 25
fac_deserters = 26
fac_mountain_bandits = 27
fac_forest_bandits = 28
fac_undeads = 29
fac_slavers = 30
fac_peasant_rebels = 31
fac_noble_refugees = 32


